%% Customizações do abnTeX2 (http://www.abntex.net.br) para
%% o Instituto de Matemática, Estatística e Computação Científica
%% da Universidade Estadual de Campinas (IMECC-UNICAMP)
%%
%% This work may be distributed and/or modified under the conditions of
%% the LaTeX Project Public License, either version 1.3 of this license
%% or (at your option) any later version. The latest version of this
%% license is in http://www.latex-project.org/lppl.txt and version 1.3
%% or later is part of all distributions of LaTeX version 2005/12/01
%% or later.
%%
%% This work has the LPPL maintenance status `maintained'.
%% 
%% The Current Maintainer of this work is Fábio Rodrigues Silva,
%% gfabinhomat@gmail.com
%%
%% Further information about abnTeX2 are available on http://www.abntex.net.br

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{imecc-unicamp}[2016/01/01 v1.0 Modelo do Instituto de%
Matemática, Estatística e Computação Científica da Universidade %
Estadual de Campinas baseado em abnTeX2]

% Repassa todos os parametros para a classe abntex2
\DeclareOption*{%
  \PassOptionsToClass{\CurrentOption}{abntex2}%
}
\ProcessOptions\relax
\LoadClass{abntex2}

% ----------------------------------------------------
% INICIO DAS ALTERAÇÕES PARA O IMECC -- UNICAMP
% ----------------------------------------------------
% ---
% Pacotes requeridos
% ---
\RequirePackage[utf8]{inputenc}
% ---

% ---
% Dados Gerais
% ---
\renewcommand{\orientadorname}{Orientador}
\renewcommand{\coorientadorname}{Coorientador}
\newcommand{\primeirafolhaname}{Primeira folha}
\newcommand{\fichacatalograficaname}{Ficha catalográfica}
% ---
\addto\captionsenglish{
    \renewcommand{\primeirafolhaname}{First page}
    \renewcommand{\fichacatalograficaname}{Cataloguing data}
    \renewcommand{\orientadorname}{Supervisor}
    \renewcommand{\coorientadorname}{Co-supervisor}
}
% ---

% ---
% Instruções de bookmark para Primeira Folha
% ---
\newenvironment{primeirafolha}[1][]{%
    \PRIVATEbookmarkthis{\primeirafolhaname}
}{\PRIVATEclearpageifneeded}
% ---

% ---
% Instruções de bookmark para Ficha Catalográfica
% ---
\renewenvironment{fichacatalografica}[1][]{%
    \thispagestyle{empty}
    \PRIVATEbookmarkthis{\fichacatalograficaname}
    \begin{SingleSpacing}
      \ABNTEXfontereduzida
}{\end{SingleSpacing}}
% ---


% ----------------------------------
% COMANDOS DE DADOS
% ----------------------------------
% Comandos de dados - título em outra língua
\providecommand{\imprimirtitulootherlang}{}
\newcommand{\titulootherlang}[1]{%
    \renewcommand{\imprimirtitulootherlang}{#1}}
%
% Comandos de dados - titulação em outra língua
\providecommand{\imprimirtitulation}{}
\newcommand{\titulation}[1]{%
    \renewcommand{\imprimirtitulation}{#1}}
%
% Comandos de dados - curso em outra língua
\providecommand{\imprimircursootherlang}{}
\newcommand{\cursootherlang}[1]{%
    \renewcommand{\imprimircursootherlang}{#1}}
%
% Comandos de dados - trabalho em outra língua
\providecommand{\imprimirtypework}{}
\newcommand{\typework}[1]{%
    \renewcommand{\imprimirtypework}{#1}}
%
% Comandos de dados - titulação
\providecommand{\imprimirtitulacao}{}
\newcommand{\titulacao}[1]{%
    \renewcommand{\imprimirtitulacao}{#1}}
%
% Comandos de dados - curso
\providecommand{\imprimircurso}{}
\newcommand{\curso}[1]{\renewcommand{\imprimircurso}{#1}}
%
% Comandos de dados - orientador
\providecommand{\imprimirorientadorRotulo}{}
\providecommand{\imprimirorientador}{}
\renewcommand{\orientador}[2][\orientadorname]%
  {\renewcommand{\imprimirorientadorRotulo}{#1}%
   \renewcommand{\imprimirorientador}{#2}}
%
% Comandos de dados - coorientador
\providecommand{\imprimircoorientadorRotulo}{}
\providecommand{\imprimircoorientador}{}
\renewcommand{\coorientador}[2][\coorientadorname]%
  {\renewcommand{\imprimircoorientadorRotulo}{#1}%
   \renewcommand{\imprimircoorientador}{#2}}
% ----------------------------------

% ---
% Definicoes compartilhadas entre Apendices e Anexos
% ---
\renewcommand{\PRIVATEapendiceconfig}[2]{%
 \setboolean{abntex@apendiceousecao}{true}%
 \renewcommand{\appendixname}{#1}
 \ifthenelse{\boolean{ABNTEXsumario-abnt-6027-2012}}{
   \renewcommand{\appendixtocname}{\texorpdfstring{\uppercase{#2}}{#2}}
  }{%
  \renewcommand{\appendixtocname}{#2}} 
 \renewcommand{\appendixpagename}{#2}
 \switchchapname{#1}% Corrected from \switchapname -> \switchchapname
 \renewcommand*{\cftappendixname}{#1 \space}
}
% ---

% ---
% Ajusta entrada Referencias
% ---
\renewcommand{\bibsection}{%
    \chapter*{\bibname}
    \bibmark
    \ifnobibintoc\else
    \phantomsection
    \addcontentsline{toc}{chapter}{\texorpdfstring{\uppercase{\bibname}}{\bibname}}
    \fi
    \prebibhook
}
% ---

% ----------------------------------
% COMANDO PARA PRIMEIRA FOLHA
% ----------------------------------
\newcommand{\imprimirprimeirafolha}{%
  \begin{primeirafolha}%    
    \noindent\includegraphics[scale=.12]{logo-unicamp.png}    
        
    \center{\ABNTEXchapterfont\Large UNIVERSIDADE ESTADUAL DE\\ CAMPINAS}
    
    \vspace*{1cm}
    
    {\ABNTEXchapterfont\large Instituto de Matemática, Estatística e\\ Computação Científica}
    
    \vspace*{2.5cm}

    {\ABNTEXchapterfont\large\MakeUppercase{\imprimirautor}}

    \vfill
    
    \begin{center}
	\ifx\otherlang\undefined
	    {\ABNTEXchapterfont\bfseries\LARGE\imprimirtitulo}
	\else
	    {\ABNTEXchapterfont\bfseries\LARGE\imprimirtitulootherlang}
	    
	    \vspace*{\fill}
	    
	    {\ABNTEXchapterfont\bfseries\LARGE\imprimirtitulo}
	\fi
    \end{center}
    \vfill

    {\large Campinas}

    {\large\imprimirdata}

    \vspace*{1cm}
  \end{primeirafolha}
}
% ----------------------------------

% ----------------------------------
% COMANDO PARA FOLHA DE ROSTO
% ----------------------------------
\makeatletter
\renewcommand{\folhaderostocontent}{
    \begin{center}
	{\ABNTEXchapterfont\large\imprimirautor}
        
        \vspace*{\fill}\vspace*{\fill}
        \ifx\otherlang\undefined
	    {\ABNTEXchapterfont\bfseries\Large\imprimirtitulo}
	\else
	    {\ABNTEXchapterfont\bfseries\Large\imprimirtitulootherlang}
	    
	    \vspace*{\fill}
	    
	    {\ABNTEXchapterfont\bfseries\Large\imprimirtitulo}
	\fi
    \end{center}
    
    \vspace*{\fill}
    
    \begin{flushright}
        \begin{minipage}[c]{.5\textwidth}
            \SingleSpacing
            \ifx\otherlang\undefined
		\imprimirtipotrabalho\ apresentada ao Instituto de Matemática, Estatística %
		e Computação Científica da Universidade Estadual de Campinas como parte dos %
		requisitos exigidos para a obtenção do título de \imprimirtitulacao\ em %
		\imprimircurso.
	    \else
		\imprimirtipotrabalho\ apresentada ao Instituto de Matemática, Estatística %
		e Computação Científica da Universidade Estadual de Campinas como parte dos %
		requisitos exigidos para a obtenção do título de \imprimirtitulacao\ em %
		\imprimircurso.
		
		\hspace{\fill} e \hspace{\fill}
		
		\imprimirtypework\ presented to the Institute of Mathematics, Statistics %
		and Scientific Computing of the University of Campinas in partial fulfillment %
		of the requirements for the degree of \imprimirtitulation\ in \imprimircursootherlang.
	    \fi
        \end{minipage}%
        \vspace*{\fill}
    \end{flushright}
    
    \noindent
    {\large\imprimirorientadorRotulo:~\imprimirorientador\par}
    \noindent
    \abntex@ifnotempty{\imprimircoorientador}{%
        {\large\imprimircoorientadorRotulo:~\imprimircoorientador}%
    }
    
    \vspace*{\fill}
    
    \begin{flushleft}
	\begin{minipage}[c]{.5\textwidth}
	    \SingleSpacing
	    {\large{Este exemplar corresponde à versão final da %
	    \imprimirtipotrabalho\ defendida
	    \ifx\femaleauthor\undefined
		pelo aluno \imprimirautor\ %
	    \else
		pela aluna \imprimirautor\ %
	    \fi
	    e orientada %
	    \ifx\femaleorientador\undefined
		pelo Prof. Dr.
	    \else
		pela Profa. Dra.
	    \fi
	    \imprimirorientador.}}
	\end{minipage}
    \end{flushleft}
    
    \vspace*{\fill}
    
    \begin{center}
        {\large Campinas}
        \par
        {\large\imprimirdata}
    \end{center}
}
\makeatother
% ----------------------------------


% ----------------------------------------------------
% FIM DAS ALTERAÇÕES PARA O IMECC -- UNICAMP
% ----------------------------------------------------